function obj = change_link(obj, matrix, linkname, varargin)
% CHANGE_LINK - Change the pred link and matching loss for a chosen matrix.
%
% Arguments:
%
% obj: An instance of @glmparams
% matrix: Name of the matrix to change (e.g., 'X', 'Y', 'Q')
% linkname: Name of the prediction link
% N: If linkname == 'binomial', this is the scale [opt: defaults to NaN].
%
% Return Values:
%
% obj: Version of input obj, with one prediction link changed
%
% Examples:
%
% 1. Change the link of X to Poisson
%
% obj = change_link(obj, 'x', 'poisson')
%
% 2. Change the link of Q to Binomial(5)
%
% obj = change_link(obj, 'q', 'binomial', 'N', 5);

% Author: ajit@cs.cmu.edu (Ajit Singh)

N = process_options(varargin, 'N', NaN);

if strcmpi(matrix, 'X')
  obj.x_pred_link_desc = linkname;
  [obj.f obj.f_prime obj.loss_f] = mk_prediction_link(linkname, N);
elseif strcmpi(matrix, 'Y')
  obj.y_pred_link_desc = linkname;
  [obj.ff obj.ff_prime obj.loss_ff] = mk_prediction_link(linkname, N);
elseif strcmpi(matrix, 'Q')
  obj.q_pred_link_desc = linkname;
  [obj.fff obj.fff_prime obj.loss_fff] = mk_prediction_link(linkname, N);
else
  error('RFA:InvalidArgument', '"%s" is not a recognized matrix name', matrix);
end

