function obj = change_scale(obj, term, scale)
% CHANGE_SCALE - Change the amount of L2-regularization on a factor
%
% Arguments:
%
% obj: An instance of @glmparams.
% term: Name of the regularizer term (one of 'g', 'h', 'i', 'j').
% value: Positive real value, scale of the regularizer.
%
% Return Values:
%
% obj: Mutated instance of obj, where one regularizer is changed

if scale >= 1
  warning('Scale > 1 seems rather odd (is %g)', scale);
end

if strcmpi(term , 'g')
  obj.scale_g = scale;
  obj.inv_g = @(x)(obj.scale_g * x);
elseif strcmpi(term, 'h')
  obj.scale_h = scale;
  obj.inv_h = @(x)(obj.scale_h * x);
elseif strcmpi(term, 'i')
  obj.scale_i = scale;
  obj.inv_i = @(x)(obj.scale_i * x);
elseif strcmpi(term, 'j')
  obj.scale_j = scale;
  obj.inv_j = @(x)(obj.scale_j * x);
elseif strcmpi(term, 'all')
  obj = change_scale(obj, 'g', scale);
  obj = change_scale(obj, 'h', scale);
  obj = change_scale(obj, 'i', scale);
  obj = change_scale(obj, 'j', scale);
else
  error('RFA:InvalidArgument', '"%s" is not a valid factor name', term);
end
