function describe_glmparams(params, varargin)
% DESCRIBE_GLMPARAMS - Describe optimization parameters output by glmparams.m
%
% Arguments:
%
% params: Optimization parameters.
%
% Return Values:
%
% N/A

% Author: ajit@cs.cmu.edu (Ajit Singh)

[print_model print_opt print_debug unused] = ...
    process_options(varargin, 'print_model', true, 'print_opt', true, ...
                    'print_debug', true);

if not(print_model) && not(print_opt) && not(print_debug)
  return;
end

if print_model
fprintf(1, '------------------ GLM Parameters --------------------------\n');

fprintf(1, '.................. Model Parameters ........................\n');
fprintf(1, 'Link on X = %s. Link on Y = %s, Link on Q = %s\n', ...
        params.x_pred_link_desc, params.y_pred_link_desc, ...
        params.q_pred_link_desc);
fprintf(1, 'All losses are matching\n');
if length(params.alpha) == 3
  fprintf(1, 'Weights (alpha) = %.3f %.3f %.3f\n', params.alpha);
else
  fprintf(1, 'Weight in favour of X over Y (alpha) = %.3f\n', params.alpha);
end
fprintf(1, 'All regularizers are L2\n');
fprintf(1, 'Scale on the parameter link (g/h/i/j): %.3e/%.3e/%.3e/%.3e\n', ...
        params.scale_g, params.scale_h, params.scale_i, params.scale_j);
fprintf(1, 'Number of latent factors (k) = %d\n', params.dims);
LogIf(params.add_bias_term, 'Added bias term as an extra dimension\n');
end % print_model

if print_opt
fprintf(1, '.................. Optimization Parameters ................\n');
LogIf(params.linesearch, 'Armijo line search (c=%g, rho=%g, min step=%f)\n', ...
      params.c, params.rho, params.mineta);
LogIf(params.linesearch, 'Armijo search only used after %d iterations\n', ...
      params.min_armijo_iter);
LogIf(params.check_condition_number && not(params.use_psd), ...
      'Checking condition number of covariance (Must be below: %g)\n', ...
      params.ill_conditioned_threshold);
LogIf(params.check_condition_number && params.use_psd, ...
      'Checking that covariance matrix is positive semi-definite\n');
fprintf(1, 'Will run at least %d iterations, and at most %d iterations\n', ...
        params.miniter, params.maxiter);
LogIf(params.stochastic_opt, 'Stochastic Optimization (batch = %d, min_scaling_factor = %.1f)\n', ...
      params.stochastic_batch_size, params.min_scaling_factor);
fprintf(1, 'Minimum decrease in objective to continue: %g percent\n', ...
        params.obj_threshold*100);
end %print_opt

if print_debug
fprintf(1, '.................. Debug Parameters ........................\n');
fprintf(1, 'Debug mode: %d\n', params.debug);
LogIf(params.debug && params.debug_deriv, ...
      'Will print message when derivative of the link is zero\n');
LogIf(params.debug && params.check_condition_number && params.debug_cond, ...
      'Will print message when the covariance matrix is ill-conditioned\n');
LogIf(params.debug && params.debug_decrease, ...
      'Will print message when the Armijo test fails: %d\n');
LogIf(params.check_condition_number && ...
      params.debug_summary_condition_number, ...
      'Will print summary of condition number for covariance of each row\n');
LogIf(params.debug && params.debug_normchange, ...
      'Will print summary of change in norm after all rows updated\n');
LogIf(params.debug && params.debug_rowstats, ...
      'Will print summary of how many rows changed, and the step lengths\n');
LogIf(params.debug && params.debug_zeroweights, ...
      'Will print message when all the weights in a row or col are zero\n');
end %print_debug

fprintf(1,'------------------------------------------------------------\n');
