function obj = enable_condition_check(obj, varargin)
% ENABLE_CONDITION_CHECK - Turn on checks on condition number of matrices
%                          that are solved/inverted.
%
%
% Examples
%
% 1. Use positive-semidefinite test to reject bogus Hessians
%
% params = enable_condition_check(params);
%
% 2. Use condition number check to reject your choice of Hessians
%
% params = enable_condition_check(params, 1e6);
%
% Arguments:
%
% obj: Instance of @glmparams
% [second arg]: Maximum acceptable condition number in [0..Inf). Default: Inf.
%
% Return Values:
%
% obj: Input objecte modified to check condition numbers.

obj.check_condition_number = true;
obj.ill_conditioned_threshold = Inf;
obj.use_psd = false;
if nargin > 1
  value = varargin{1};
  assert(isbetween(value, 0, Inf, 'closed'));
  if value < 10000
    warning('%g is an overly stringent threshold for the condition num', ...
            value);
  end
  obj.ill_conditioned_threshold = value;
else
  obj.use_psd = true;
end
