function obj = enable_stochastic(obj, varargin)
% ENABLE_STOCHASTIC - Turn on stochastic gradient descent, which forces us
% to disable certain checks that do not apply -- the objective can increase
% and so line search needs to be disabled.
%
% Arguments:
%
% obj: An instance of @glmparams
% [second arg]: Batch size for each update [opt: default 100]
%
% Return Values:
%
% obj: Modified input, will use stochastic gradient methods and no linesearch.

batch_size = 100;
if nargin > 1
  batch_size = varargin{1};
end
if obj.maxiter > 20
  warning('Stochastic optimization will run for a lot of iterations (%d)', ...
          obj.maxiter);
end
if obj.add_bias_term
  warning('Bias term and stochastic gradients do not play nicely together');
end

obj.stochastic_opt = true;
obj.stochastic_batch_size = batch_size;
obj.debug_cond = false;
obj.debug_decrease = false;
obj.debug_zeroweights = true;
obj = enable_condition_check(obj);
obj = disable_linesearch(obj);


