function obj = subsasgn(obj, S, B)
% SUBSASGN - Subscripted assignments (mutator for member variables)
%
% The only way to assign variables to objects is obj.S = B. Other forms of
% subsasgn, such as obj(S) = B or obj{S} = B, are reserved for cell arrays
% of objects. Cell arrays of @glmparams are not supported.
%
% Arguments:
%
% obj: An instance of @glmparams
% S: Field to mutate.
% B: Value to change the field to.
%
% Return Values:
%
% obj: Mutated version of the input object, obj.S = B now.

% Author: ajit@cs.cmu.edu (Ajit Singh)

% Fields we allow to user to change via subsasn -- ie, parameters with no
% critical dependencies or effects on other parameters.
blessed = {'dims', 'show_iter', 'add_bias_term', 'maxiter', 'miniter', ...
           'min_scaling_factor', 'alpha', 'obj_threshold', ...
           'inline_standard_weights', ...
           'no_adjusted_dependent_variates', ...
           'densify_rows', ...
           'debug', 'debug_deriv', 'debug_cond', ...
           'debug_decrease', 'debug_summary_condition_number', ...
           'debug_normchange', 'debug_rowstats', 'debug_zeroweights'};

name = S.subs;
if length(strmatch(name, blessed, 'exact')) == 0 && ...
      length(strmatch(name, fieldnames(obj), 'exact')) > 0
  error('RFA:InvalidArgument', 'Cannot alter field "%s"', name);
end

obj = builtin('subsasgn', obj, S, B);
