function [tex tey] = evaluate_error(model, split, params, varargin)
% EVALUATE_ERROR - Compute the error defined by the split on the test data.
%
% Arguments:
%
% model: An instance of @model3f, containing factors U, V, and Z.
% split: A split of the data, containing fields xtest, exi, exj, ytest, eyi, eyj
% params: Optimization parameters. f/ff define the prediction links.
% mode: Controls whether the error is computed on X, Y, or both ('all'). Opt.
%
% Return Values:
%
% tex: Error on the test data from X.
% tey. Error on the test data from Y.

% Author: Ajit Singh (ajit@cs.cmu.edu)

mode = process_options(varargin, 'mode', 'all');

if strcmpi(mode, 'X')
  tex = xerr(model, split, params);
  tey = NaN;
elseif strcmpi(mode, 'Y')
  tex = NaN;
  tey = yerr(model, split, params);
elseif strcmpi(mode, 'all')
  tex = xerr(model, split, params);
  tey = yerr(model, split, params);
else
  error('Parameter mode = %s is invalid', mode);
end

function val = xerr(model, split, params)

k = params.dims;
U = model.U;
V = model.V;
%V = model.V(:, [model.core_v model.bias_v_x]);
xhat = generate_pred(split.exi, split.exj, U, V, params.f);
val = split.eval_x(split.xtest, xhat);
val = full(val);

function val = yerr(model, split, params)

k = params.dims;
%V = model.V(:, [model.core_v model.bias_v_y]);
V = model.V;
Z = model.Z;
yhat = generate_pred(split.eyi, split.eyj, V, Z, params.ff);
val = split.eval_y(split.ytest, yhat);
val = full(val);
