function C = hist_mmmf(model, params, split, plot_rows, plot_cols, varargin)
% HIST_MMMF - Plot a histogram of the values predicted by the model on test data
%
% [Designed for use with the Netflix ratings matrix]
% hist_pred(model, params, split, 3, 2)
%
% Arguments:
%
% model: Instance of @model3f
% params: Contains the prediction link
% split: Contains the test split (xtest,exi,exj)
% plot_rows: Number of rows to plot
% plot_cols: Number of cols to plot
%
% Return Values:
%
% c: Confusion matrix

[U V] = unwrap(model);
values = full(sort(unique(split.xtest)));
xhat = generate_pred_mmmf(split.exi, split.exj, U, V, params.dims, params.f);
xhat(xhat > max(values)) = max(values);
fprintf('mae = %f\n', mean(abs(xhat-split.xtest)));
plot_hist(split.xtest, xhat, values, plot_rows, plot_cols);
C = confmat(split.xtest, xhat, values);
suptitle('Test Predictions -- X');

function plot_hist(x, xhat, values, plot_rows, plot_cols, varargin)

check_nonnegative(plot_rows);
check_nonnegative(plot_cols);

max_plots = plot_rows * plot_cols;
WarnIf(max_plots > 10, 'Asking for a lot of plots (%d)', max_plots);

figure;
subplot(plot_rows, plot_cols, 1);
plotidx = 1;
for value = values
  subplot(plot_rows, plot_cols, plotidx);
  plotidx = plotidx + 1;
  idx = find(x == value);
  [N,X] = hist(xhat(idx), [0:max(values)]);
  bar(X, N, 'BarWidth', 0.75, 'FaceColor', 'b', 'EdgeColor', 'w');
  set(gca, 'Xtick', values);
  set(gca, 'FontSize', 11);
  xlim([0 max(values)]);
  grid;
  title(sprintf('Value == %.2f', value));
end


