function obj = model3f(varargin)
% MODEL3F - Constructor for @model3f object.
%
% An instance of a 3-factor model, consisting of factors U, V, and Z where
% we assume X = UV' and Y = VZ'.
%
% Usage
%
% 1. As a copy constructor
%
% obj = model3f(anotherModel3f);
%
% 2. As a non-trivial constructor
%
% obj = model3f(U, V, Z);

% Author: ajit@cs.cmu.edu (Ajit Singh)

error(nargchk(1, 4, nargin));

classname = 'model3f';
if nargin == 1
  firstArg = varargin{1};
  if isa(firstArg, classname)
    obj = firstArg;
  else
    error('RFA:model3f', ...
          'First argument ("%s") is not an instance of @model3f', inputname(1));
  end
  return;
elseif nargin == 4
  obj = init_fields(varargin{1}, varargin{2}, varargin{3}, varargin{4});
  obj = class(obj, classname);
  return;
else
  error('Wrong number of arguments (is %d)', nargin);
end

function obj = init_fields(U, V, Z, params)
% INIT_FIELDS -- Define default parameters for model3f.m.

check_factor(U);
check_factor(V);
check_factor(Z);
% $$$ check_type(params, 'glmparams');

obj.U = U;
obj.V = V;
obj.Z = Z;

if params.add_bias_term
  k = params.dims;
  check_dims(U, rows(U), k+4, 'U');
  check_dims(V, rows(V), k+4, 'V');
  check_dims(Z, rows(Z), k+4, 'Z');
else
  k = params.dims;
  check_dims(U, rows(U), k, 'U');
  check_dims(V, rows(V), k, 'V');
  check_dims(Z, rows(Z), k, 'Z');
end

function status = check_factor(U)
% CHECK_FACTOR -- Assertion checks for a factor matrix

if not(isnumeric(U))
  error('Matrix "%s" is not numeric', inputname(1));
end

