function [tex tey teq] = evaluate_error(model, split, params, varargin)
% EVALUATE_ERROR - Compute the error defined by the split on the test data.
%
% Arguments:
%
% model: An instance of @model4f.
% split: A split of the data, containing fields xtest, exi, exj, ytest, eyi, eyj
% params: Optimization parameters. f/ff define the prediction links.
% mode: Controls whether the error is computed on X, Y, or both ('all'). Opt.
%
% Return Values:
%
% tex: Error on the test data from X.
% tey. Error on the test data from Y.

% Author: Ajit Singh (ajit@cs.cmu.edu)

mode = process_options(varargin, 'mode', 'all');

if strcmpi(mode, 'X')
  tex = xerr(model, split, params);
  tey = NaN;
  teq = NaN;
elseif strcmpi(mode, 'Y')
  tex = NaN;
  tey = yerr(model, split, params);
  teq = NaN;
elseif strcmpi(mode, 'Q')
  tex = NaN;
  tey = NaN;
  teq = qerr(model, split, params);
elseif strcmpi(mode, 'all')
  tex = xerr(model, split, params);
  tey = yerr(model, split, params);
  teq = qerr(model, split, params);
else
  error('Parameter mode = %s is invalid', mode);
end

function val = xerr(model, split, params)

xhat = generate_pred(split.exi, split.exj, model.U, model.V, params.f);
val = split.eval_x(split.xtest, xhat);
val = full(val);

function val = yerr(model, split, params)

yhat = generate_pred(split.eyi, split.eyj, model.V, model.Z, params.ff);
val = split.eval_y(split.ytest, yhat);
val = full(val);

function val = qerr(model, split, params)

qhat = generate_pred(split.eqi, split.eqj, model.V, model.R, params.fff);
val = split.eval_q(split.qtest, qhat);
val = full(val);
