function hist_pred(model, params, split, plot_rows, plot_cols, varargin)
% HIST_PRED - Plot a histogram of the values predicted by the model on test data
%
% [Designed for use with the Netflix ratings matrix]
% hist_pred(model, params, split, 3, 2)
%
% Arguments:
%
% model: Instance of @model3f
% params: Contains the prediction link
% split: Contains the test split (xtest,exi,exj)
% plot_rows: Number of rows to plot
% plot_cols: Number of cols to plot
%
% Return Values:
%
% N/A

[U V Z] = unwrap(model);
values = full(sort(unique(split.xtest)));
xhat = generate_pred(split.exi, split.exj, U, V, params.f);
xhat(xhat > max(values)) = max(values);
plot_hist(split.xtest, xhat, values, plot_rows, plot_cols);
title('Test Predictions -- X');

function plot_hist(x, xhat, values, plot_rows, plot_cols, varargin)

check_nonnegative(plot_rows);
check_nonnegative(plot_cols);

max_plots = plot_rows * plot_cols;
WarnIf(max_plots > 10, 'Asking for a lot of plots (%d)', max_plots);

figure;
subplot(plot_rows, plot_cols, 1);
plotidx = 1;
for value = values
  subplot(plot_rows, plot_cols, plotidx);
  plotidx = plotidx + 1;
  i = find(x == value);
  hist(xhat(i),50);
  xlim([min(xhat) max(xhat)]);
end
