function obj = model4f(varargin)
% MODEL4F - Constructor for @model4f object.
%
% An instance of a 4-factor model, consisting of factors U, V, Z, and R where
% we assume X = UV', Y = VZ', and Q = VR'.
%
% Usage
%
% 1. As a copy constructor
%
% obj = model4f(anotherModel4f);
%
% 2. As a non-trivial constructor
%
% obj = model4f(U, V, Z, R, params);

% Author: ajit@cs.cmu.edu (Ajit Singh)

error(nargchk(1, 5, nargin));

classname = 'model4f';
if nargin == 1
  firstArg = varargin{1};
  if isa(firstArg, classname)
    obj = firstArg;
  else
    error('RFA:model4f', ...
          'First argument ("%s") is not an instance of @model4f', inputname(1));
  end
  return;
elseif nargin == 5
  obj = init_fields(varargin{1}, varargin{2}, varargin{3}, varargin{4}, varargin{5});
  obj = class(obj, classname);
  return;
else
  error('Wrong number of arguments (is %d)', nargin);
end

function obj = init_fields(U, V, Z, R, params)
% INIT_FIELDS -- Define default parameters for model3f.m.

check_factor(U);
check_factor(V);
check_factor(Z);
check_factor(R);
if cols(U) ~= cols(V) || cols(U) ~= cols(Z) || cols(U) ~= cols(R)
  error('Embedding dimension of U V Z R differ (%d vs. %d vs. %d vs. %d)', ...
        cols(U), cols(V), cols(Z), cols(R));
end
obj.U = U;
obj.V = V;
obj.Z = Z;
obj.R = R;

function status = check_factor(U)
% CHECK_FACTOR -- Assertion checks for a factor matrix

if not(isnumeric(U))
  error('Matrix "%s" is not numeric', inputname(1));
end

