function info = find_info(m, mid, type)
% FIND_INFO - Extract information about a specific movie.
%
% Arguments:
%
% m: An instance @movie.
% mid: Integer id for a movie.
% type: Type of extra information desired ('names')
%
% Return Values:
%
% info: A structure containing the movie id, genre ids, actor ids,
% and director ids. If type == 'name' We replace the ids with the
% actual strings for the movie name, genres, actors, and directors.

assert(m.Nm > 0, 'There are no movies in the given object');
assert(isbetween(mid, 1, m.Nm, 'closed'), 'Not a valid movie id (%d)', mid);

info.movie = mid;
info.genres = find(m.genres(:, mid));
info.actors = find(m.actors(:, mid));
info.directors = find(m.directors(:, mid));

if ( strcmp(type,'names') )
    info.movie = m.movie_names(info.movie);
    info.genres = m.genre_names(info.genres);
    info.actors = m.talent_names(info.actors);
    info.directors = m.talent_names(info.directors);
end
