function users = find_users_with_ratings(m, low, high)
% FIND_USERS_WITH_RATINGS - Return the ids of user who rate at
% between [low, high] different movies.
%
% Arguments:
%
% m: Instance of @movie class.
% low: Lower bound on the number of ratings.
% high: Upper bound on the number of ratings.
%
% Return Values:
%
% users: A (possibly empty) list of users who have rated at least
% low and at most high different movies.

assert(low >= 0, 'Low must be in [0, Inf] (is %d)', low);
assert(high >= 0, 'High must be in [0, Inf] (is %d)', high);

%nr = sum(m.ratings|m.ratings,2);
nr = sum(logical(m.ratings), 2);
users = intersect(find(nr>=low), find(nr<=high));
