function value = eval_ap(obj,entities,varargin)
% EVAL_MAP - Average precision
%
% value = eval_map(obj,entities)
% Computes the average precision of a ranking:
%    1/|entities| * \sum_k precision@k * rel(vk)
% where rel(vk) is an indicator that is 1 iff one of the members of
% entities is at position k in the ranking.

check_score_invariant(obj);
check_uniqueness_invariant(obj);
if isempty(entities)
  error('@ranking/score: no entities, cannot compute average rank.');
end

[threshold unused] = process_options(varargin, 'threshold', Inf);

sobj = sort(obj);
r = length(entities);
value = 0;
for e = entities
  i = find(sobj.rank==e);
  if i <= threshold
    prec = 1/i * length(intersect(sobj.rank(1:i), entities));
    value = value + prec;
  else
    r = r - 1;
  end
end
if r <= 0
  value = 0;
else
  value = value / r;
end
