%RANKING(...) constructor for a ranking object (for link prediction)
%   A ranking consists of a set of pairs 
%   (entity1,score1) ... (entityN,scoreN)
%   where the scores induce a total ordering. An example of link
%   prediction is finding the likely authors for a set of papers.
%   For each paper, we generate a ranking of authors based on how
%   likely it is that they are an author of the paper. Ideally the
%   true authors are at the top of the list.

function obj = ranking(varargin)

if nargin == 0 
    obj = init_fields;
    obj = class(obj,'ranking');
    return;
end
firstArg = varargin{1};
if isa(firstArg,'ranking')
    obj = firstArg;
    return;
end

obj = init_fields;
obj = class(obj,'ranking');

if nargin == 2
    obj.rank = reshape(varargin{1},1,length(varargin{1}));
    obj.score = reshape(varargin{2},1,length(varargin{2}));
    obj.desc = 'No desc';
    obj = sort(obj);
elseif nargin == 3 
    obj.rank = reshape(varargin{1},1,length(varargin{1}));
    obj.score = reshape(varargin{2},1,length(varargin{2}));
    obj.desc = varargin{3};
    obj = sort(obj);
end


% Default initializer
function obj = init_fields()

obj.rank = [];
obj.score = [];
obj.desc = 'Empty ranking';