function [cpu models] = exp_ch_alpha_matters(splits, basepar, alphas, varargin)
% EXP_CH_ALPHA_MATTERS - Run the pLSI-pHITS model for different alpha's
%
% Arguments:
%
% splits: Cell array of splits
% basepar: Basic parameters shared by all runs. Instance of @glmparams.
% alpha: Vector of weights in favour of data matrix X over data matrix Y.
%
% Return Values:

% Author: ajit@cs.cmu.edu (Ajit Singh)

check_type(splits, 'cell');
check_type(basepar, 'glmparams');
assert(all(isbetween(alphas, 0.0, 1.0, 'closed')), ...
       'Expected all between 0 and 1. Got alphas = [%s]', ...
       sprintf(' %.1f ', alphas));

init_model = mk_init_model(splits{1}, basepar.dims);
assert(not(varargin_contains('init_model', varargin{:})));

params = cell(1, length(alphas));
for i = 1:length(alphas)
  params{i} = basepar;
  params{i}.alpha = alphas(i);
end

init_random_seed;
start_time_msg = sprintf('Started %s\n', datestr(now,'dd-mmm-yyyy HH:MM:SS'));
fprintf(1, '%s', start_time_msg);

[models cpu] = run_ch(splits, params, 'init_model', init_model, varargin{:});

fprintf(1, '%s', start_time_msg);
fprintf(1, 'Finished %s\n', datestr(now,'dd-mmm-yyyy HH:MM:SS'));

function model = mk_init_model(split,K)

N = split.X_train;
A = split.Y_train';
Nw = rows(N);
Np = cols(N);
Na = rows(A);
model.TermFactors = normalize_rows(rand(K,Nw)); % p(ti|zk)
model.AuthFactors = normalize_rows(rand(K,Na)); % p(al|zk)
model.DocMixing = normalize_cols(rand(K,Np)); % p(zk|dj)
