function [metric cpu] = exp_mmmf(splits, basepar, varargin)
% EXP_MMF - Run the newton and conjugate gradient forms of MMMF.
%
% Arguments:
%
% splits: Cell array of splits (length s)
% basepar: Basic parameters shared by all runs. Instance of @glmparams
%
% Return Values:
%
% metric: structure (fields: newton, conjgrad), each contains the error for
% each split
% cpu: structure(fields: newton, conjgrad), each contains the training time
% for each split

check_type(splits, 'cell');
check_type(basepar, 'glmparams');

[newt_iters cg_iters unused] = ...
    process_options(varargin, 'newton_iterations', Inf, 'cg_iterations', Inf);

params = basepar;
if isfinite(newt_iters)
  params.maxiter = newt_iters;
end
[metric.newton cpu.newton] = run_mmmf(splits, {params}, 'type', 'newton', varargin{:});

params = basepar;
if isfinite(cg_iters)
  params.maxiter = cg_iters;
end
[metric.conjgrad cpu.conjgrad] = run_mmmf(splits, {params}, 'type', 'conjgrad', ...
                                          varargin{:});

metric.newton = cell2mat(metric.newton)';
metric.conjgrad = cell2mat(metric.conjgrad)';
metric.desc = func2str(splits{1}.eval_x);
cpu.newton = cell2mat(cpu.newton)';
cpu.conjgrad = cell2mat(cpu.conjgrad)';
cpu.desc = 'training time (sec)';
