function value = logloss(X,W,AB,f)
% LOGLOSS(X,W,AB,f) - Compute the weighted log-likelihood of the
% data under a binomial distribution.
%
% Arguments:
%
% X: Data (m x n)
% W: Non-negative weights (m x n)
% AB: Natural parameters (m x n)
% f: Prediction link (currently not used)
%
% Return Values:
%
% value: The weighted log-likelihood assuming that x_{ij} ~ Bin(f(AB)_{ij})

idx = find(X & W);

x = X(idx);
if not(all(x == 1))
  non_one = x(x ~= 1)
  error('RFA:InvalidArgument',...
        'Log-loss only makes sense when the observations are binary');
end

%t = sigmoid(AB(idx));
% inline sigmoid func
ab = AB(idx);
t = 1./(1+exp(-ab));
if any(t == 0)
  value = Inf;
  return;
end
w = W(idx);
log_likelihood = sum(w.*log(t));

idx = find((X == 0) & W);

%t = sigmoid(AB(idx));
% inline sigmoid func
ab = AB(idx);
t = 1./(1+exp(-ab));
if any(t == 1)
  value = Inf;
  return;
end
w = W(idx);
log_likelihood = log_likelihood + sum(w.*log(1-t));

value = -log_likelihood;

% at alpha == 0 or 1 can break
%if not(isfinite(value))
%  warning('RFA:InvalidAnswer', 'Log-likelihood should not be infinite here');
%end

% $$$   [i, j] = find(W);
% $$$   idx = sub2ind(size(X), i, j);
% $$$   x = X(idx);
% $$$   w = W(idx);
% $$$   t = AB(idx);
% $$$   xs = (2*x-1).*t;
% $$$   breg = log(1 + exp(-xs));
% $$$   if not(all(isfinite(breg)))
% $$$     idx = find(not(isfinite(breg)));
% $$$     x(idx)
% $$$     t(idx)
% $$$     warning('Value not finite at %d/%d samples',...
% $$$             length(find(not(isfinite(breg)))), length(breg));
% $$$   end
% $$$   value = sum(w .* breg);
  
% $$$   [i,j] = find(X==1 & W); idx = sub2ind(size(X),i,j);
% $$$   x = X(idx);
% $$$   r = Xest(idx);
% $$$   w = W(idx);
% $$$   if length(find(r==0)) > 0
% $$$     warning('%f frac incorrect zeros (%d)',...
% $$$             length(find(r==0))/length(r),length(r));
% $$$     %r(find(r==0))=1; % essentially really bad mistakes are free !
% $$$     r(find(r==0)) = max(r);
% $$$   end
% $$$   value = value + sum(w.*x.*(-log(r)));
% $$$ 
% $$$   [i,j] = find(X==0 & W); idx = sub2ind(size(X),i,j);
% $$$   x = X(idx);
% $$$   r = 1-Xest(idx);
% $$$   w = W(idx);
% $$$   if length(find(r==0)) > 0
% $$$     warning('%f frac incorrect ones (%d)',...
% $$$             length(find(r==0))/length(r),length(r));
% $$$     %r(find(r==0))=1;
% $$$     r(find(r==0)) = max(r);
% $$$   end
% $$$   value = value + sum(w.*x.*(-log(r)));

