function plot_alpha_matters(models, splits, params, varargin)
% PLOT_ALPHA_MATTERS - Plot the results of exp_alpha_matters
%
% plot_alpha_matters(models, splits, params, varargin)
%
% Arguments:
%
% ...
%
% Return Values:
%
% N/A

% Author: Ajit singh (ajit@cs.cmu.edu)

error(nargchk(3, Inf, nargin));

check_type(models, 'cell');
check_type(splits, 'cell');
check_length(splits, rows(models));
check_length(params, cols(models));

[loss.x loss.y] = evaluate_errors(models, splits, params);
[err std_dev] = reduce_data(loss.x);
alpha = extract_alpha(params);

plot_impl(alpha, err, std_dev, 'xlabel', '\alpha', 'ylabel', 'Test Loss -- X', ...
          varargin{:});

figure;
[err std_dev] = reduce_data(loss.y);
plot_impl(alpha, err, std_dev, 'xlabel', '\alpha', 'ylabel', 'Test Loss -- Y', ...
          varargin{:});

function alpha = extract_alpha(params)

alpha = repmat(NaN, 1, length(params));
for p = 1:length(params)
  alpha(p) = params{p}.alpha;
end

function [err std_dev] = reduce_data(loss)
% REDUCE_DATA -
%
% Arguments:
%
% loss: s x p x m cell array of errors for each split-parameter pair.
%
% Return Values:
%
% err: Measure of the error for a given parameter setting.
% std_dev: Std. dev of the error at each parameter setting.

[average dev] = average_columns(loss);
res = repmat(NaN, 1, length(average));
bar = repmat(NaN, 1, length(average));
for p = 1:length(average)
  err(p) = average{p}(end);
  std_dev(p) = dev{p}(end);
end

function plot_impl(alpha, y, std_dev, varargin)

[xlab ylab linewidth usegrid suptit use_errorbars unused] = ...
    process_options(varargin, 'xlabel', false, 'ylabel', false, ...
                    'linewidth', 2, 'usegrid', true, 'title', [ ], ...
                    'errorbars', false);

if use_errorbars
  errorbar(alpha, y, std_dev./2, 'linewidth', linewidth);
else
  plot(alpha, y, 'linewidth', linewidth);
end

if not(isempty(suptit))
  title(suptit);
end
if xlab
  xlabel(xlab);
end
if ylab
  ylabel(ylab);
end
if usegrid;
  grid;
end

set(gca, 'XMinorTick', 'on', 'TickDir', 'out');
set(gca, 'YMinorTick', 'on');
set(gca, 'FontName', 'Helvetica', 'FontSize', 12);
