function plot_newton(obj, cpu, varargin)
% PLOT_NEWTON - Plot the results of exp_newton
%
% plot_newton(obj, cpu)
% Plot the training error vs. cpu-time curves for the Newton and gradient
% methods.
%
% Arguments:
%
% Return Values:
%
% N/A

% Author: Ajit Singh (ajit@cs.cmu.edu)

error(nargchk(2, Inf, nargin));

hn = plot_method(obj.newton, cpu.newton);
hold on;
hg = plot_method(obj.gradient, cpu.gradient);
set(gca, 'FontSize', 11);
xlabel('Training Time (s)', 'interpreter', 'latex', 'FontSize', 16);
ylabel('Training Loss $\mathcal{L}$', 'interpreter', 'latex', ...
       'FontSize', 16);
legend('Newton', 'Gradient')
legend boxoff;
grid on;
set(hn, 'LineStyle', '-', 'LineWidth', 1.0, 'Color', 'Black');
set(hn, 'Marker', 'o', 'MarkerFaceColor', [0.5 0.5 0.5], ...
        'MarkerEdgeColor', [0 0 0], 'MarkerSize', 8.0);
set(hg, 'LineStyle', '-', 'LineWidth', 2.0, 'Color', 'Black');
set(hg, 'Marker', '.', 'MarkerFaceColor', [1 1 1], ...
        'MarkerEdgeColor', [0 0 0], 'MarkerSize', 4.0);

set(gca, 'Box', 'off');
set(gca, 'FontSize', 14);
xlim([0 350])

function h = plot_method(obj_method, cpu_method)

X = cell2mat(cpu_method);
Y = cell2mat(obj_method);

x = mean(X,1);
y = mean(Y,1);

sx = std(X, [ ], 1);
sy = std(Y, [ ], 1);

h = semilogy(x, y);

