function [models cputime] = run_ch(splits, params, varargin)
% RUN_CH - Compare pLSI-pHITS on different splits and settings
%
% [ ] = run_ch(splits, params, varargin)
%
% Arguments:
%
% splits: A cell array of splits (length s)
% params: Cell array of different optimization parameters (length p)
%
% Return Values:
%
% models: s x p cell matrix where each cell is a struct containing the
%         final model produced by this approach (see ch_em.m).
% cputime: s x p cell matrix where each cell contains the CPU time required
%          to train the model.

% Author: Ajit Singh (ajit@cs.cmu.edu)

error(nargchk(2, Inf, nargin));

check_type(splits, 'cell');
check_type(params, 'cell');

models = cell(length(splits), length(params));
cputime = cell(length(splits), length(params));
for s = 1:length(splits)
  for p = 1:length(params)
    fprintf(1, ['============== Split %d/%d | Parameters %d/%d '...
                '==================\n'], ...
            s, length(splits), p, length(params));
    [model train_time] = ch_em(splits{s}.X_train, splits{s}.Y_train', ...
                               params{p}, varargin{:});
    cputime{s,p} = train_time;
    models{s,p} = model;
  end
end
