function script_exp_alpha_matters(base, sm, params, alphas, nreps, varargin)
% SCRIPT_EXP_ALPHA_MATTERS - Wrapper for exp_alpha_matters
%
% script_exp_alpha_matters(base, sm, params, alpha, nreps, varargin)
%
% WARNING: Saving models to disk can require a lot of space, especially if
% we run for many iterations.
%
% Arguments:
%
% base: Directory where logs and results are stored.
% sm: Data set. Must have data(sm) method.
% params: Optimization and model parameters
% alphas: Vector of relative data weights to try. Overrides params.alpha
% nreps: Number of repetitions
% varargin: ...
%
% Return Values:
%
% N/A

% Author: Ajit Singh (ajit@cs.cmu.edu)

check_nonnegative(nreps);

[share_splits unused] = process_options(varargin, 'share_splits', false);

process = script_init_process(base);

if share_splits
  splits = script_load_splits(fullfile(base, 'shared_splits.mat'));
else
  dataobj = data(sm, varargin{:});
  fprintf(1, '%s', dataobj.description);
  splitfcn = @( )(dataobj.test_train_splits(0.1, 0.1, nreps));
  splits = script_create_splits(base, splitfcn, process);
end

[obj cpu models params] = ...
    exp_alpha_matters(splits, params, alphas, varargin{:});

script_save_results(base, process, 'obj', 'cpu', 'models', 'params');
