function script_exp_compare_ranking(base, sm, basepar, alphas, nreps, varargin)
% SCRIPT_EXP_ALPHA_MATTERS - Wrapper for exp_alpha_matters
%
% script_exp_alpha_matters(base, sm, basepar, alpha, nreps, varargin)
%
% WARNING: Saving models to disk can require a lot of space. We strip
% information we don't need out of the splits (including everything about
% matrix Y), but most of the space is used to store models, which contain
% length(alpha) * nreps * \sum_t (basepar.dims x
% number_of_entities_of_type_t) real numbers.
%
% Arguments:
%
% base: Directory where logs and results are stored.
% sm: Data set. Must have data(sm) method.
% basepar: Optimization and model parameters
% alphas: Vector of relative data weights to try. Overrides basepar.alpha
% nreps: Number of repetitions
% varargin: ...
%
% Return Values:
%
% N/A

% Author: Ajit Singh (ajit@cs.cmu.edu)

check_nonnegative(nreps);

[share_splits unused] = process_options(varargin, 'share_splits', false);

process = script_init_process(base);

if share_splits
  splits = script_load_splits(fullfile(base, 'shared_splits.mat'));
else
  dataobj = data(sm, varargin{:});
  fprintf(1, '%s', dataobj.description);
  splitfcn = @( )(dataobj.test_train_splits(0.1, 0.1, nreps));
  splits = script_create_splits(base, splitfcn, process);
end

[cpu models splits alphas desc] = ...
    exp_compare_ranking(splits, basepar, alphas, varargin{:});

script_save_results(base, process, 'cpu', 'models', 'alphas', 'splits', 'desc');
