function script_exp_mmmf(base, sm, param, nreps, varargin)
% SCRIPT_EXP_MMMF - Wrapper for exp_mmmf
%
% script_exp_mmmf(base, sm, params, nreps, varargin)
% Generate nreps splits of the data set sm, and run both the Newton and
% conjugate gradient versions of max-margin matrix factorization using
% the same set of parameters.
%
% Arguments:
%
% base: Directory where logs and results are stored.
% sm: Data set. Must have data(sm) method.
% params: Optimization and model parameters.
% nreps: Numbers of repetitions (splits to make)
% varargin: ...
%   'hold_out_frac': fraction of ratings to hold out (default 0.1)
%
% Return Values:
%
% N/A

% Author: Ajit Singh (ajit@cs.cmu.edu)

[share_splits frac unused] = process_options(varargin, 'share_splits', false,...
                                             'hold_out_frac', 0.1);
check_type(param, 'glmparams');
check_nonnegative(nreps)
assert(isbetween(frac, 0.0, 1.0, 'closed'), ...
       'Expected between 0 and 1. Got %f.\n', frac);

process = script_init_process(base);

if share_splits
  splits = script_load_splits(fullfile(base, 'shared_splits.mat'));
else
  dataobj = data(sm, varargin{:}, 'ignore_zeros', true);
  fprintf(1, '%s', dataobj.description);
  splitfcn = @( )(dataobj.test_train_splits(frac, frac, nreps));
  splits = script_create_splits(base, splitfcn, process);
end

[metric cpu] = exp_mmmf(splits, param, varargin{:});

script_save_results(base, process, 'metric', 'cpu');
