function script_exp_stochastic(base, sm, params, batches, niters_newton, ...
                               niters_stochastic, nreps, varargin)
% SCRIPT_EXP_STOCHASTIC - Wrapper for exp_stochastic. Allows for different
% machines to run different splits.
%
% script_exp_stochastic(base, sm, params, batches, niters_newton, ...
%                       niters_stochastic, nreps, varargin)
% script_exp_stochastic(base, sm, params, [1 100 1000], niters_newton, ...
%                       niters_stochastic, nreps, 'min_scaling_factor', ...
%                       [2 1.5 1.5])
%
% WARNING: Saving the models can take a lot of space on disk, even using
% the default compressed binary format (.mat). This is especially true if
% you let it run for many iterations. Best to keep nreps small.
%
% Arguments:
%
% base: Directory where logs and results are stored.
% sm:   Data set (must have data(sm) method)
% params: Optimization and model parameters (dims, alpha set here)
% niters_newton: Number of iterations of Newton to use.
% niters_stochastic: Number of iterations of Stochastic Newton to use.
% nreps: Number of splits to use.
% varargin: ...
%
% Return Values:
%
% N/A

check_nonnegative(nreps);

[share_splits unused] = process_options(varargin, 'share_splits', false);

process = script_init_process(base);

if share_splits
  splits = script_load_splits(fullfile(base, 'shared_splits.mat'));
else
  dataobj = data(sm, varargin{:});
  fprintf(1, '%s', dataobj.description);
  splitfcn = @( )(dataobj.test_train_splits(1/10, 1/10, nreps));
  splits = script_create_splits(base, splitfcn, process);
end

[obj cpu models params] = ...
    exp_stochastic(splits, params, batches, niters_newton, ...
                   niters_stochastic, varargin{:});

script_save_results(base, process, 'obj', 'cpu', 'models', 'params');
