function splits = script_create_splits(base, splitfcn, process)
% SCRIPT_CREATE_SPLITS - Create training and test splits. Saves splits.
%
% splits = script_create_splits(base, splitfcn, process)
% Generates the splits and handles the details of saving them to a file.
%
% Arguments:
%
% base: Directory splits will be saved to.
% splitfcn: An zero-argument function that generates the splits.
% process: Unique identifier for the process.
%
% Return Values:
%
% splits: Training and test splits. Format depends on splitfcn.

% Author: Ajit Singh (ajit@cs.cmu.edu)

assert(isdir(base), '\"%s\" is not a directory', base);

filename = fullfile(base, sprintf('splits-%d.mat', process));
assert(not(exist(filename, 'file')), 'File %s already exists', filename);

fprintf('Creating new splits...\n');
splits = splitfcn( );
filename = fullfile(base, sprintf('splits-%d.mat', process));

% We don't need the training data in the saved split.
fprintf('Warning: To save space we remove training data from saved split.\n');
fullsplits = splits;
splits = remove_training_data_from_split(splits);
save(filename, 'splits');
splits = fullsplits;

fprintf('%s contains %d splits\n', filename, length(splits));
