function splits = script_load_splits(filename)
% SCRIPT_LOAD_SPLITS - Load training and test splits from a file
%
% splits = script_load_splits(filename)
%
% Arguments:
%
% filename: Name of the splits file. File must be in matlab format,
%           and must have a variable named splits.
%
% Return Values:
%
% splits: The splits loaded from the file

% Author: Ajit Singh (ajit@cs.cmu.edu)

assert(exist(filename, 'file'), 'File %s does not exist', filename);

splits_varname = 'splits';

fprintf('Loading splits from \"%s\"...', filename);
vars = load(filename);
if not(isfield(vars, splits_varname))
  error(sprintf('\"%s\" did not contain variable: %s\n',...
                filename, splits_varname));
end
splits = vars.splits;
fprintf('contains %d splits\n', length(splits));

