function script_save_results(base, process, varargin)
% SCRIPT_SAVE_RESULTS - Save variables, close logs.
%
% script_save_results(base, process, 'cpu', 'models')
% Saves the variable names passed in the variable length argument to the
% given directory (in results-%d.mat where %d is the process id).
%
% Arguments:
%
% base: Directory to save variables in
% process: Process identifier
% varargin: Contains the names of the variables to save
%
% Return Values:
%
% N/A

% Author: Ajit Singh (ajit@cs.cmu.edu)

assert(isdir(base), '\"%s\" is not a directory', base);

short_filename = sprintf('results-%d.mat', process);
filename = fullfile(base, short_filename);
assert(not(exist(filename, 'file')), 'File %s already exists', filename);

% Save to tmp before saving to the given path, since that is likely to fail
altfilename = sprintf('%s.mat', tempname);
fprintf(1, 'Saving to %s as well as %s. Just in case of quota issues.\n', ...
        altfilename, filename);
evalin('caller', create_save_command(altfilename, varargin{:}));

fprintf(1, 'Saving data to %s\n', filename);
evalin('caller', create_save_command(filename, varargin{:}));

fprintf(1, 'Closing diary-%d.txt\n', process);
diary off;
fclose('all');

function cmd = create_save_command(filename, varargin)
% CREATE_SAVE_COMMAND - Create the save command in string form

cmd = sprintf('save(\''%s\''%s)', filename, sprintf(',\''%s\''', varargin{:}));
