function split = change_error(split, matrix, type)
% CHANGE_ERROR - Change the error function used in a split (e.g., created
%                by @movie or @nips.
%
% Arguments:
%
% split: struct with eval_x, eval_y, eval_q fields
% matrix: string, one of the matrices 'x', 'y', 'q'
% type: error to change it to: 'rmse', 'mae', 'mse'

% Author: Ajit Singh (ajit@cs.cmu.edu)

if strcmpi(matrix, 'x')
  split.eval_x = type_to_function(type);
elseif strcmpi(matrix, 'y')
  split.eval_y = type_to_function(type);
elseif strcmpi(matrix, 'q')
  split.eval_q = type_to_function(type);
else
  error('Invalid matrix: %s', matrix);
end

function fcn = type_to_function(type)

if strcmpi(type, 'rmse')
  fcn = @rmse;
elseif strcmpi(type, 'mae')
  fcn = @mae;
elseif strcmpi(type, 'mse')
  fcn = @mse;
else
  error('Invalid type: %s', type);
end
