function check_splits(splits)
% CHECK_SPLITS - Check whether the splits all refer to data of the same size
%                and whether the loss functions are probably all the same.
%
% Arguments:
%
% splits: Cell array of splits (1 x s)
%
% Return Values:
%
% N/A

check_type(splits, 'cell');
assert(length(splits) > 0);
X = splits{1}.X_train;
Y = splits{1}.Y_train;
eval_x = splits{1}.eval_x;
eval_y = splits{1}.eval_y;
[m n] = size(X);
r = cols(Y);

for i = 1:length(splits)
  check_dims(splits{i}.X_train, m, n, sprintf('splits{%d}', i));
  check_dims(splits{i}.Y_train, n, r, sprintf('splits{%d}', i));
  check_error_function(splits{i}.eval_x, eval_x);
  check_error_function(splits{i}.eval_y, eval_y);
end

function check_error_function(f, g)
% CHECK_ERROR_FUNCTION - Tests whether two binary functions agree on probe
%                        values.

x = [0 -rand(1,5) rand(1,5)];
xhat = rand(1, length(x));
assert(f(x, xhat) == g(x, xhat), ...
       '%s and %s do not match', func2str(f), func2str(g));

