function [error_x error_y] = evaluate_errors(models, splits, params)
% EVALUATE_ERRORS - Compute the test error for each split + parameter pair
%                   on a set of models.
%
% Arguments:
%
% Let s = length(splits); p = length(params); m = length(models);
%
% models: s x p x m cell tensor where each entry is an instance of @model3f.
% splits: 1 x s cell array of test/train splits for a data set. For example,
%         see @movie/data.m.
% params: 1 x p cell array of optimization settings. Each entry an instance
%         of @glmparams. We assume the losses are the same for each instance,
%         or the results we be completely uninterpretable.
%
% Return Values:
%
% 

check_splits(splits)
check_type(splits, 'cell');
check_type(params, 'cell');

% TODO(ajit): Test that the error funcs of each split are the same. See
% check_splits

error_x = cell(rows(models), cols(models));
error_y = cell(rows(models), cols(models));
for s = 1:rows(models)
  for p = 1:cols(models)
    mods = models{s, p};
    vx = zeros(1, length(mods));
    vy = zeros(1, length(mods));
    for k = 1:length(mods)
      % HACK: if the type didn't load correctly
      m = model3f(mods(k).U, mods(k).V, mods(k).Z, params{p});
      [vx(k) vy(k)] = evaluate_error(m, splits{s}, params{p});
    end
    error_x{s, p} = vx;
    error_y{s, p} = vy;
  end
end
