function [loss_x loss_y] = evaluate_losses(models, splits, params)
% EVALUATE_LOSSES - Compute the test loss for each split + parameter pair
%                   on a set of models.
%
% Arguments:
%
% Let s = length(splits); p = length(params); m = length(models)
%
% models: s x p x m cell tensor where each entry is an instance of @model3f.
% splits: 1 x s cell array of test/train splits for a data set. For example,
%         see @movie/data.m.
% params: 1 x p cell array of optimization settings. Each entry an instance
%         of @glmparams. We assume the losses are the same for each instance,
%         or the results we be completely uninterpretable.
%
% Return Values:
%
% loss_x = s x p cell matrix where each entry is a length m vector of test
%          losses on the X data matrix for each model.
% loss_y = Same layout as lx, except the losses are for the Y data matrix.

check_splits(splits)
check_type(splits, 'cell');
check_type(params, 'cell');

% TODO(ajit): Test that the losses of each split are the same. See
% check_splits

loss_x = cell(rows(models), cols(models));
loss_y = cell(rows(models), cols(models));
for s = 1:rows(models)
  for p = 1:cols(models)
    mods = models{s, p};
    vx = zeros(1, length(mods));
    vy = zeros(1, length(mods));
    for k = 1:length(mods)
      [vx(k) vy(k)] = evaluate_loss(mods(k), splits{s}, params{p});
    end
    loss_x{s, p} = vx;
    loss_y{s, p} = vy;
  end
end
