function est = generate_pred(ridx, cidx, A, B, f)
% GENERATE_PRED - Return the value of f(AB') at the positions given by
%                 ridx and cidx.
%
% est = generate_pred(ridx, cidx, A, B, f)
%
% Arguments:
%
% ridx: Vector of row indices (1 x t)
% cidx: Vector of column indices (1 x t)
% A: Row factors (m x k)
% B: Column factors (k x n)
% f: Element-wise prediction link
%
% Return Values:
%
% est: The i^th elt is the value of f(AB') at position (ridx(i), cidx(i)).

check_dims(ridx, rows(cidx), cols(cidx), 'ridx');
assert(cols(A) == cols(B), 'Factors are bogus');
est = f(sum(A(ridx,:).*B(cidx,:), 2))';

% $$$ % Initial implementation, slow.
% $$$ est = repmat(NaN, 1, length(ridx));
% $$$ for i = 1:length(est)
% $$$   r = ridx(i);
% $$$   c = cidx(i);
% $$$   est(i) = f(A(r,:)*B(c,:)');
% $$$ end
