function est = generate_pred_mmmf(ridx, cidx, U, V, k, f)

assert(cols(U) == cols(V));

b = cols(U) - k;
est = ones(1, length(ridx));

% If there were R unique values {1...R} in the data then we chose R-1
% thresholds corresponding to binary predictors:
%   x < 2 ?
%   x < 3 ?
%   ...
%   x < R ?
% and so the decoding is to assume all the ratings are initially 1,
% then then increments their value if they are not smaller than the
% given threshold.
%
% TODO(ajit): Remove assumption that the values are 1...R instead of
% some arbitrary sequence. None of the rating data works like that, but
% it is nice to be general.

% $$$ for r = 1:b
% $$$   xy = sum(U(ridx,1:k) .* V(cidx,1:k),2);
% $$$   thresh = U(:,k+r);
% $$$   thresh = thresh(ridx);
% $$$   idx = (xy < thresh)' & (est == r);
% $$$   length(find(idx))
% $$$   est(idx) = est(idx) + 1;
% $$$ end

for r = 1:b
  latents = [1:k k+r];
  prob = f(sum(U(ridx,latents) .* V(cidx,latents),2))';
  idx = (prob < 0.5) & (est == r);
  est(idx) = est(idx) + 1;
end
